@@ -56,7 +56,7 @@ class FormController(Controller):
             def main_page(self):
                 # getting the context must be the first action done here: it allows the
                 # method to raise AccessDenied if needed.
-                self.context = self.context()
+                self.context = self.get_context()
                 self.context.update(form=cls.form())
                 return self.render(cls.template, context=self.context)
 
@@ -66,7 +66,7 @@ class FormController(Controller):
                 # method to raise AccessDenied if needed.
                 self.context = self.get_context()
                 form = cls.form(formdata=form_data)
-                context.update(form=form)
+                self.context.update(form=form)
                 if not form.validate():
                     return self.on_invalid_form(form, **kw)
                 else:
